@@ -12,7 +12,10 @@ import helpsk.pandas
 import helpsk.pandas_style
 import helpsk.plot
 import helpsk.sklearn_eval
-import helpsk.sklearn_search
+import helpsk.sklearn_search_base
+import helpsk.sklearn_search_bayesian
+import helpsk.sklearn_search_bayesian_base
+import helpsk.sklearn_search_bayesian_classification
 import helpsk.sklearn_pipeline
 import helpsk.string
 import helpsk.utility
